#include "GLObject.h"

#ifndef LongHall_h
#define LongHall_h

class LongHall : public GLObject {
private:
    float squareSize; // フィールドの大きさ
    float split; // 分割数
    float tileSize; // 分割後のタイルの大きさ
    float tileHeight; // 床のデコボコの高さ
    
public:
    LongHall(){
        reset();
    }
    
    void reset(){
        GLObject::reset();
        
        squareSize = 32;
        split = 16;
        tileSize = squareSize/split;
        tileHeight = 1.0;
    }
    
    // TankActionからの流用
    void displayFloor(){
        for (int z=0; z<split; z++) {
            for (int x=0; x<split; x++) {
                float baseX = -squareSize/2 + x*tileSize;
                float baseZ = -squareSize/2 + z*tileSize;
                
                if ((x+z)%2 == 0) {
                    glMaterialfv(GL_FRONT, GL_DIFFUSE, GLColor::GREEN);
                }else{
                    glMaterialfv(GL_FRONT, GL_DIFFUSE, GLColor::GREEN2);
                }
                
                glBegin(GL_QUADS);
                glNormal3d(0, 1, 0);
                glVertex3d(baseX , (z%2==1)&&(x%2==1)?tileHeight:0, baseZ);
                glVertex3d(baseX+tileSize, (z%2==1)&&(x%2==0)?tileHeight:0, baseZ);
                glVertex3d(baseX+tileSize, (z%2==0)&&(x%2==0)?tileHeight:0, baseZ+tileSize);
                glVertex3d(baseX, (z%2==0)&&(x%2==1)?tileHeight:0, baseZ+tileSize);
                glEnd();
                
            }
        }
    }
    
    void displayHoll(){
        glPushMatrix();
        glTranslatef(0, -4, 0);
        displayFloor();
        glPopMatrix();
        
        glPushMatrix();
        glRotatef(180, 0, 0, 1);
        glTranslatef(0, -4, 0);
        displayFloor();
        glPopMatrix();
        
        glPushMatrix();
        glRotatef(90, 0, 0, 1);
        glTranslatef(0, -5, 0);
        displayFloor();
        glPopMatrix();
        
        glPushMatrix();
        glRotatef(-90, 0, 0, 1);
        glTranslatef(0, -5, 0);
        displayFloor();
        glPopMatrix();
    }
 
    void display(){
        GLObject::display();
        
        glMaterialf(GL_FRONT, GL_AMBIENT, 0.1);
        glMaterialf(GL_FRONT, GL_SPECULAR, 0.1);
        glMaterialf(GL_FRONT, GL_SHININESS, 0.0);
        
        glPushMatrix();
        glTranslatef(0, 0, 18);
        displayHoll();
        glPopMatrix();
        
        for (int i=1; i<30; i+=2) {
            glPushMatrix();
            glTranslatef(0, 0, -18*i+4*i);
            displayHoll();
            glPopMatrix();
        }
    }
};


#endif
